4.8. umbra.components.addons.traceUi.traceUi — Umbra 1.0.9 documentation

# 4.8. umbra.components.addons.traceUi.traceUi

traceUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `TraceUi` Component Interface class and others helper objects.

Others:

## 4.8.1. Module Attributes

`umbra.components.addons.traceUi.traceUi.` `LOGGER`

`umbra.components.addons.traceUi.traceUi.` `COMPONENT_UI_FILE`

## 4.8.2. Classes

class `umbra.components.addons.traceUi.traceUi.` `TraceUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `umbra.components.addons.traceUi.traceUi` Component Interface class.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `refreshNodes`

    This signal is emited by the `TraceUi` class when `TraceUi.model` class property model nodes needs to be refreshed. ( pyqtSignal )

  `dockArea`

    Property for self.__dockArea attribute.

    Returns: | self.__dockArea.
    Return type: | int

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `settingsSection`

    Property for self.__settingsSection attribute.

    Returns: | self.__settingsSection.
    Return type: | unicode

  `model`

    Property for self.__model attribute.

    Returns: | self.__model.
    Return type: | CollectionsModel

  `view`

    Property for self.__view attribute.

    Returns: | self.__view.
    Return type: | QWidget

  `headers`

    Property for self.__headers attribute.

    Returns: | self.__headers.
    Return type: | OrderedDict

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

    Returns: | Method success.
    Return type: | bool

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

    Returns: | Method success.
    Return type: | bool

  `getSelectedNodes`()

    Returns the View selected nodes.

    Returns: | View selected nodes.
    Return type: | dict

  `getSelectedModules`()

    Returns the View selected modules.

    Returns: | View selected modules.
    Return type: | list

  `traceModules`(modules, pattern=u'.*', flags=2)

    Traces given modules using given filter pattern.

    Parameters: | modules (list) – Modules to trace. pattern (unicode) – Matching pattern. flags (int) – Matching regex flags.
    Returns: | Method success.
    Return type: | bool

  `untraceModules`(modules)

    Untraces given modules.

    Parameters: | modules (list) – Modules to untrace.
    Returns: | Method success.
    Return type: | bool

  `getModules`()

    Sets the registered Modules.

    Returns: | Registered modules.
    Return type: | list

  `setModules`(modules=None)

    Sets the modules Model nodes.

    Parameters: | modules (list) – Modules to set.
    Returns: | Method success.
    Return type: | bool